@@ -28,10 +28,10 @@
 
 #include "exchange-config-listener.h"
 
-#include "exchange-account.h"
-#include "e-folder-exchange.h"
-#include "e2k-marshal.h"
-#include "e2k-uri.h"
+#include <exchange-account.h>
+#include <e-folder-exchange.h>
+#include <e2k-marshal.h>
+#include <e2k-uri.h>
 #include "mail-stub-listener.h"
 
 #include <e-util/e-dialog-utils.h>
@@ -359,7 +359,7 @@ add_folder_esource (ExchangeAccount *account,
 	gboolean is_contacts_folder = TRUE, group_new = FALSE, source_new = FALSE;
 	const char *offline = NULL;
 	int mode;
-	ESourceList *source_list;
+	ESourceList *source_list = NULL;
 
 	client = gconf_client_get_default ();
 
@@ -540,7 +540,7 @@ remove_account_esource (ExchangeAccount *account,
 	gboolean found_group;
 	const char *source_uid;
 	GConfClient *client;
-	ESourceList *source_list;
+	ESourceList *source_list = NULL;
 
 	/* Remove the ESource group, to remove all the folders in a component */
 
@@ -640,7 +640,7 @@ remove_folder_esource (ExchangeAccount *account,
 	const char *source_uid;
 	GSList *ids, *temp_ids, *node_to_be_deleted;
 	GConfClient *client;
-	ESourceList *source_list;
+	ESourceList *source_list = NULL;
 
 	client = gconf_client_get_default ();
 
@@ -764,6 +764,7 @@ account_added (EAccountList *account_list, EAccount *account)
 {
 	ExchangeConfigListener *config_listener;
 	ExchangeAccount *exchange_account;
+	ExchangeAccountResult result;
 
 	if (!is_active_exchange_account (account))
 		return;
@@ -801,8 +802,8 @@ account_added (EAccountList *account_list, EAccount *account)
 
 	g_signal_emit (config_listener, signals[EXCHANGE_ACCOUNT_CREATED], 0,
 		       exchange_account);
-	add_sources (exchange_account);
-	exchange_account_connect (exchange_account);
+	//add_sources (exchange_account);
+	exchange_account_connect (exchange_account, NULL, &result);
 }
 
 struct account_update_data {
